"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheckAuth = void 0;
const _1 = require(".");
const ResponseFactory_1 = require("./ResponseFactory");
/**
 * TO USE ENSURE CLASS HAS A PROPERTY CALLED authService. authService MUST IMPLEMENT THE AuthService INTERFACE.
 *
 * @param settings The permissions & roles to check for
 */
const CheckAuth = (settings) => (target, propertyKey, descriptor) => {
    const originalMethod = descriptor.value;
    descriptor.value = function (...args) {
        return __awaiter(this, void 0, void 0, function* () {
            const context = args[0];
            const req = args[1];
            const authService = this.authService;
            if (authService == undefined)
                throw Error("authService IS NOT DEFINED! authService MUST BE DEFINED AND IMPLEMENT THE AuthService INTERFACE TO USE THE AUTH DECORATOR!");
            const validator = (type, settings) => __awaiter(this, void 0, void 0, function* () {
                const expected = settings[type];
                let missing = [];
                for (let i = 0; i < expected.length; i++) {
                    const item = expected[i];
                    let present = false;
                    if (type == 'permission')
                        present = yield authService.hasPermission(context, req, item);
                    if (type == 'role')
                        present = yield authService.hasRole(context, req, item);
                    if (!present)
                        missing.push(item);
                }
                if (missing.length == 0)
                    return;
                const error = {
                    type: type,
                    message: `Missing ${type}: ${missing.join(', ')}`,
                    expected: expected,
                    missing: missing,
                    request: req
                };
                return error;
            });
            const errors = [];
            if (settings.permission) {
                const e = yield validator('permission', settings);
                e ? errors.push(e) : null;
            }
            if (settings.role) {
                const e = yield validator('role', settings);
                e ? errors.push(e) : null;
            }
            if (errors.length === 0)
                return originalMethod.apply(this, args);
            const errorMessages = [];
            errors.forEach(error => {
                (0, _1.validationErrorLog)(context, error);
                errorMessages.push(error.message);
            });
            return (0, ResponseFactory_1.default)(400, 'Validation Errors', errorMessages);
        });
    };
    return descriptor;
};
exports.CheckAuth = CheckAuth;
//# sourceMappingURL=AuthDecorator.js.map