"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateAuth = exports.validate = exports.validationErrorLog = void 0;
const _1 = require(".");
function validationErrorLog(context, error) {
    context.log.error(JSON.stringify(error));
}
exports.validationErrorLog = validationErrorLog;
function validate(context, req, settings) {
    return __awaiter(this, void 0, void 0, function* () {
        const validator = (type, settings) => {
            const all = req[type] ? Object.keys(req[type]) : [];
            const expected = settings[type];
            const missing = expected.filter((value) => !all.includes(value));
            if (missing.length == 0)
                return;
            const error = {
                type: type,
                message: `Missing ${type} ${(type === 'query' || type === 'body') ? 'paramaters:' : ':'} ${missing.join(', ')}`,
                expected: expected,
                missing: missing,
                all: all,
                request: req
            };
            return error;
        };
        const errors = [];
        if (settings.body) {
            const e = validator('body', settings);
            e ? errors.push(e) : null;
        }
        if (settings.query) {
            const e = validator('query', settings);
            e ? errors.push(e) : null;
        }
        if (settings.headers) {
            const e = validator('headers', settings);
            e ? errors.push(e) : null;
        }
        if (errors.length === 0)
            return null;
        const errorMessages = [];
        errors.forEach(error => {
            validationErrorLog(context, error);
            errorMessages.push(error.message);
        });
        return (0, _1.responseFactory)(400, 'Validation Errors', errorMessages);
    });
}
exports.validate = validate;
function validateAuth(context, req, settings, authService) {
    return __awaiter(this, void 0, void 0, function* () {
        const validator = (type, settings) => __awaiter(this, void 0, void 0, function* () {
            const expected = settings[type];
            let missing = [];
            for (let i = 0; i < expected.length; i++) {
                const item = expected[i];
                let present = false;
                if (type == 'permission')
                    present = yield authService.hasPermission(context, req, item);
                if (type == 'role')
                    present = yield authService.hasRole(context, req, item);
                if (!present)
                    missing.push(item);
            }
            if (missing.length == 0)
                return;
            const error = {
                type: type,
                message: `Missing ${type}: ${missing.join(', ')}`,
                expected: expected,
                missing: missing,
                request: req
            };
            return error;
        });
        const errors = [];
        if (settings.permission) {
            const e = yield validator('permission', settings);
            e ? errors.push(e) : null;
        }
        if (settings.role) {
            const e = yield validator('role', settings);
            e ? errors.push(e) : null;
        }
        if (errors.length === 0)
            return null;
        const errorMessages = [];
        errors.forEach(error => {
            validationErrorLog(context, error);
            errorMessages.push(error.message);
        });
        return (0, _1.responseFactory)(400, 'Validation Errors', errorMessages);
    });
}
exports.validateAuth = validateAuth;
//# sourceMappingURL=Validators.js.map