"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("./index");
const FunctionRunner_1 = require("../FunctionRunner");
describe('Example Test', () => {
    let mockService;
    let mockAuthService;
    let api;
    beforeEach(() => {
        mockService = jasmine.createSpyObj('ExampleService', ['message']);
        mockService.message.and.returnValue('This is a message from the mocked service!');
        mockAuthService = jasmine.createSpyObj('AuthService', ['hasRole', 'hasPermission']);
        mockAuthService.hasPermission.and.returnValue(true);
        mockAuthService.hasRole.and.returnValue(true);
        api = new index_1.HTTPTest(mockService, mockAuthService);
    });
    it('Should work with a mocked service', () => __awaiter(void 0, void 0, void 0, function* () {
        const azureFunc = api.build();
        const response = yield (0, FunctionRunner_1.mockedRequestFactory)(azureFunc, { url: '/test/wow', query: { 'name': 'Joe' } });
        const resBody = JSON.parse(response.body);
        expect(response.status).toEqual(200);
        expect(resBody.success).toEqual(true);
        expect(resBody.data).toEqual(undefined);
        expect(resBody.message).toEqual('Hello, Joe. This HTTP triggered function executed successfully. Service Message: This is a message from the mocked service!');
    }));
    it('Should work with a GET request', () => __awaiter(void 0, void 0, void 0, function* () {
        const azureFunc = api.build();
        const response = yield (0, FunctionRunner_1.mockedRequestFactory)(azureFunc, { url: '/test/wow', method: 'GET', query: { 'name': 'Joe' } });
        const resBody = JSON.parse(response.body);
        expect(response.status).toEqual(200);
        expect(resBody.success).toEqual(true);
        expect(resBody.data).toEqual(undefined);
        expect(resBody.message).toEqual('Hello, Joe. This HTTP triggered function executed successfully. Service Message: This is a message from the mocked service!');
    }));
    it('Should work with a POST request', () => __awaiter(void 0, void 0, void 0, function* () {
        const azureFunc = api.build();
        const response = yield (0, FunctionRunner_1.mockedRequestFactory)(azureFunc, { url: '/test/wow', method: 'POST', body: { 'name': 'Joe' }, query: { 'user': 'Alex' } });
        const resBody = JSON.parse(response.body);
        expect(response.status).toEqual(200);
        expect(resBody.success).toEqual(true);
        expect(resBody.data).toEqual(undefined);
        expect(resBody.message).toEqual('Hello, Joe. This HTTP triggered function executed successfully. Service Message: This is a message from the mocked service!');
    }));
});
//# sourceMappingURL=index.spec.js.map